## 🔄 Template Synchronization

This PR synchronizes the repository with the [jebel-quant/rhiza](https://github.com/jebel-quant/rhiza) template.

### 📊 Change Summary

- **1** files added
- **17** files modified
- **0** files deleted

### 📁 Changes by Category

#### Configuration Files

<details>
<summary>Modified (2)</summary>

- 📝 `.pre-commit-config.yaml`
- 📝 `ruff.toml`

</details>

#### GitHub Actions Workflows

<details>
<summary>Added (1)</summary>

- ✅ `.github/workflows/rhiza_mypy.yml`

</details>

<details>
<summary>Modified (7)</summary>

- 📝 `.github/workflows/rhiza_benchmarks.yml`
- 📝 `.github/workflows/rhiza_book.yml`
- 📝 `.github/workflows/rhiza_ci.yml`
- 📝 `.github/workflows/rhiza_marimo.yml`
- 📝 `.github/workflows/rhiza_release.yml`
- 📝 `.github/workflows/rhiza_security.yml`
- 📝 `.github/workflows/rhiza_sync.yml`

</details>

#### Rhiza Configuration

<details>
<summary>Modified (3)</summary>

- 📝 `.rhiza/history`
- 📝 `.rhiza/rhiza.mk`
- 📝 `.rhiza/utils/version_matrix.py`

</details>

#### Rhiza Scripts

<details>
<summary>Modified (1)</summary>

- 📝 `.rhiza/scripts/release.sh`

</details>

#### Tests

<details>
<summary>Modified (4)</summary>

- 📝 `tests/test_rhiza/test_makefile_api.py`
- 📝 `tests/test_rhiza/test_release_script.py`
- 📝 `tests/test_rhiza/test_version_matrix.py`
- 📝 `tests/tests.mk`

</details>

---

**🤖 Generated by [rhiza](https://github.com/jebel-quant/rhiza-cli)**

- Template: `jebel-quant/rhiza@main`
- Last sync: 2026-01-18T15:29:13Z
- Sync date: 2026-01-19T01:44:12.060993+00:00